@@ -168,7 +168,7 @@ html_engine_get_document_color (HTMLEngine *engine)
 			return NULL;
 		else {
 			HTMLObject *obj;
-			gint offset, index;
+			gint offset;
 
 			obj = html_engine_text_style_object (engine, &offset);
 			return obj
@@ -435,6 +435,7 @@ html_engine_set_color (HTMLEngine *e, HTMLColor *color)
 			rv = FALSE;
 	}
 	html_color_unref (e->insertion_color);
+
 	e->insertion_color = color;
 	html_color_ref (e->insertion_color);
 
